## 🎯 Objetivos

Este desafío consiste en implementar una API backend básica para una lista de tareas utilizando Fastify y MongoDB. La API proporcionará operaciones CRUD en tareas, filtrado basado en diferentes patrones y gestión de datos.

1. **Objetivo 1**: Implementar los endpoints para crear una tarea de la lista de tareas y extraerlas (GET y POST). Debe seguir la **Tabla de Endpoints** que encontrarás en el README del repositorio.
2. **Objetivo 2**: Crear un endpoint adicional que implemente `filtrado`. Las especificaciones de formato para estos endpoints están en la sección **Objetivo 2: Filtrado** del README en el repositorio de GitHub.
3. **Bonus**: ¡Asegúrate de validar los datos de entrada del usuario en cada endpoint! Hay varias formas de hacerlo, elige la que prefieras.

### Tabla de Endpoints

| URL          | Verbo HTTP | Condición        | Estado devuelto | Formato devuelto                                     |
| ------------ | ---------- | ---------------- | :-------------: | ---------------------------------------------------- |
| `/todos/all` | GET        | Siempre          |       200       | `{ message: 'string', value: 'Array'}`               |
| `/todos/:id` | GET        | Encontrado       |       200       | `{ message: 'string', value: 'Object'}`              |
| `/todos/:id` | GET        | No encontrado    |       404       | `{ message: 'string', value: {}}`                    |
| `/todos`     | POST       | Datos válidos    |       201       | `{ message: 'string', value: 'String' (created ID)}` |
| `/todos`     | POST       | Datos no válidos |       400       | `{ message: 'string', value: {}}`                    |

### Objetivo 2: Filtrado

El endpoint admite filtrado mediante `query`. El filtrado está disponible para los campos `title`, `categories` y `done`.

El endpoint `/todos/filter` extrae (GET) todas las tareas que coincidan con el filtro aplicado. Si no se aplica ningún filtro, el endpoint no realiza ninguna acción.

| URL             | Verbo HTTP | Condición | Estado devuelto | Formato devuelto                       |
| --------------- | ---------- | --------- | :-------------: | -------------------------------------- |
| `/todos/filter` | GET        | Siempre   |       200       | `{ message: 'string', value: 'Array'}` |

### Cómo probar

Para probar la aplicación, necesitas tener una instancia de MongoDB desplegada localmente.
Puedes instalar MongoDB en tu máquina de prueba, usar una instancia en la nube o usar el script `mongodb.js`.

Para usar el último, primero ejecuta el servidor de MongoDB con el siguiente comando:
`node mongodb.js`

Luego, ejecuta el servidor web de la API con el comando `make start`.

**NOTAS**: Si lo desean, pueden utilizar otro stack tecnológico distinto a Fastify y MongoDB, como por ejemplo ExpressJS y SQLite.
