/*
 * File: \index.js                                                             *
 */

// Fastify as our API HTTP Web Server

// Setup dotfiles into process.env
require("dotenv").config();

/**
 * @type {import('fastify').FastifyInstance} Instance of Fastify
 */
const fastify = require("fastify")({
  logger: false,
});

let uri = process.env.MONGO_URL || "mongodb://localhost:27017/backend-js-api";

fastify.register(require("@fastify/mongodb"), {
  forceClose: true,
  url: uri,
});

fastify.register(require("./project/routes/todo.js"));

// Run server
const start = async () => {
  try {
    const port = process.env.PORT || 3000;
    await fastify.listen({ port });
    console.log(`✅ Server listening on: ${port}`);
  } catch (err) {
    console.error(err);
    fastify.log.error(err);
    process.exit(1);
  }
};

start();
